@@ -352,7 +352,7 @@ text_new (void)
 static void
 text_set (GtkWidget *widget, icalproperty *prop)
 {
-  const char *text = NULL;
+  char *text = NULL;
   char *s;
   GtkWidget *textview;
   GtkTextBuffer *buffer;
@@ -376,6 +376,9 @@ text_set (GtkWidget *widget, icalproperty *prop)
     s = g_strcompress (text);
     gtk_text_buffer_set_text (buffer, s, -1);
     g_free (s);
+#if LIBICAL_MEMFIXES
+    g_free (text);
+#endif
   } else {
     gtk_text_buffer_set_text (buffer, "", -1);
   }
