@@ -114,9 +114,9 @@ summary_func (GtkTreeViewColumn *tree_column,
   if (due) {
     char *temp, *date;
     
-    date = ical_util_get_human_date (due);
+    date = ical_util_get_human_due_date (due);
     
-    temp = g_strdup_printf (_("%s (due %s)"), summary, date);
+    temp = g_strdup_printf ("%s (%s)", summary, date);
 
     g_free (summary);
     g_free (date);
@@ -164,7 +164,7 @@ summary_func (GtkTreeViewColumn *tree_column,
 }
 
 static void
-icon_func (GtkTreeViewColumn *column, GtkCellRenderer *cell,
+url_icon_func (GtkTreeViewColumn *column, GtkCellRenderer *cell,
            GtkTreeModel *model, GtkTreeIter *iter,
            gpointer user_data)
 {
@@ -177,6 +177,23 @@ icon_func (GtkTreeViewColumn *column, GtkCellRenderer *cell,
   g_free (url);
 }
 
+static void
+note_icon_func (GtkTreeViewColumn *column, GtkCellRenderer *cell,
+           GtkTreeModel *model, GtkTreeIter *iter,
+           gpointer user_data)
+{
+  KotoTask *task;
+
+  gtk_tree_model_get (model, iter, COLUMN_TASK, &task, -1);
+
+  /* TODO: I wonder how slow this is */
+  g_object_set (cell, "visible",
+                icalcomponent_get_description (task->comp) ? TRUE : FALSE,
+                NULL);
+
+  koto_task_unref (task);
+}
+
 /*
  * Custom function for interactive searches.
  */
@@ -223,6 +240,29 @@ on_url_activated (KotoCellRendererPixbuf *cell, const char *path, GtkTreeView *v
   }
 }
 
+/*
+ * Callback when the URL icon is clicked, to start a web browser.
+ */
+static void
+on_note_activated (KotoCellRendererPixbuf *cell, const char *path, GtkTreeView *view)
+{
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+  KotoTask *task = NULL;
+  
+  model = gtk_tree_view_get_model (view);
+
+  if (!gtk_tree_model_get_iter_from_string (model, &iter, path))
+    return;
+
+  gtk_tree_model_get (model, &iter, COLUMN_TASK, &task, -1);
+  
+  if (task) {
+    koto_platform_edit_task (task);
+    koto_task_unref (task);
+  }
+}
+
 /*
  * Object methods.
  */
@@ -383,7 +423,8 @@ koto_task_view_init (KotoTaskView *self)
 
   treeview = GTK_TREE_VIEW (self);
 
-  /* Ugly kludge for current Maemo */
+  /* Ugly kludge for current Maemo TODO: can this be removed now that Chinook is
+     released? */
   if (g_object_class_find_property (G_OBJECT_GET_CLASS (self), "allow-checkbox-mode"))
     g_object_set (G_OBJECT (self), "allow-checkbox-mode", FALSE, NULL);
 
@@ -418,7 +459,14 @@ koto_task_view_init (KotoTaskView *self)
   g_signal_connect (renderer, "activated", G_CALLBACK (on_url_activated), self);
   gtk_tree_view_column_pack_end (column, renderer, FALSE);
   gtk_tree_view_column_set_cell_data_func (column, renderer,
-                                           icon_func, treeview, NULL);
+                                           url_icon_func, treeview, NULL);
+
+  renderer = koto_cell_renderer_pixbuf_new ();
+  g_object_set (renderer, "icon-name", "text-x-generic", NULL);
+  g_signal_connect (renderer, "activated", G_CALLBACK (on_note_activated), self);
+  gtk_tree_view_column_pack_end (column, renderer, FALSE);
+  gtk_tree_view_column_set_cell_data_func (column, renderer,
+                                           note_icon_func, treeview, NULL);
   
   gtk_tree_view_append_column (treeview, column);
 }
