@@ -30,6 +30,7 @@
 #include <libkoto/koto-meta-group.h>
 #include <libkoto/koto-group-store.h>
 #include <libkoto/koto-hint-entry.h>
+#include <libkoto/koto-date-parser.h>
 #include <libkoto/koto-task.h>
 #include <libkoto/koto-task-store.h>
 #include <libkoto/koto-task-view.h>
@@ -41,6 +42,15 @@
 #include <libkoto/koto-undo-action.h>
 #include <libkoto/koto-undo-manager.h>
 
+#if WITH_OWL
+#include <owlwindowmenu.h>
+#endif
+
+#if WITH_UNIQUE
+#include <unique/unique.h>
+#endif
+
+#include "ui.h"
 #include "window-util.h"
 
 static GtkWidget *window, *combo, *treeview, *new_entry;
@@ -51,26 +61,6 @@ static GtkTreeModel *task_store, *filter, *group_filter_store, *group_selector_s
 static GHashTable *edit_dialog_hash;
 static KotoUndoManager *undo_manager;
 
-void
-koto_platform_open_url (const char *url)
-{
-  char cmd[1024];
-
-  g_snprintf (cmd, sizeof (cmd), "gnome-open \"%s\"", url);  
-  if (g_spawn_command_line_async (cmd, NULL))
-    return;
-
-  g_snprintf (cmd, sizeof (cmd), "xdg-open \"%s\"", url);  
-  if (g_spawn_command_line_async (cmd, NULL))
-    return;
-
-  g_snprintf (cmd, sizeof (cmd), "firefox \"%s\"", url);  
-  if (g_spawn_command_line_async (cmd, NULL))
-    return;
-
-  g_warning ("Cannot start gnome-open, xdg-open, or firefox");
-}
-
 static gboolean
 select_uid (char *uid)
 {
@@ -117,6 +107,8 @@ create_component (const char *text, KotoGroup *default_group)
 {
   char *group = NULL;
   icalcomponent *comp;
+  GDate *date;
+  char *parsed_text = NULL;
 
   /* TODO: from here onwards should be moved into libkoto so that other
      frontends can have the same logic. */
@@ -156,9 +148,20 @@ create_component (const char *text, KotoGroup *default_group)
         group = guess;
     }
   }
+  
+  /* Parse any date hints in the text */
+  date = koto_date_parse (text, &parsed_text);
+  if (date) {
+    struct icaltimetype due;
+    due = icaltime_from_day_of_year (g_date_get_day_of_year (date),
+				     g_date_get_year (date));
+    icalcomponent_set_due (comp, due);
+  }
 
-  icalcomponent_add_property (comp, icalproperty_new_summary (text));
-
+  icalcomponent_add_property (comp,
+			      icalproperty_new_summary (parsed_text ?: text));
+  g_free (parsed_text);
+  
   /* If a group wasn't specified in the task, use the current group */
   if (group == NULL) {
     if (default_group &&
@@ -256,6 +259,8 @@ edit_task (KotoTask *task)
                   "undo-manager", undo_manager,
                   NULL);
     
+    window_bind_state (GTK_WINDOW (dialog), "task-editor");
+
     gtk_widget_show (dialog);
     
     g_hash_table_insert (edit_dialog_hash, task, dialog);
@@ -441,7 +446,7 @@ on_about_action (GtkAction *action, gpointer user_data)
                          "name", _("Tasks"),
                          "version", VERSION,
                          "logo-icon-name", "tasks",
-                         "copyright", "Copyright \302\251 2007 OpenedHand Ltd",
+                         "copyright", "Copyright \302\251 2007-2008 OpenedHand Ltd",
                          "authors", authors,
                          "artists", artists,
                          "translator-credits", _("translator-credits"),
@@ -452,7 +457,6 @@ on_about_action (GtkAction *action, gpointer user_data)
                          NULL);
 }
 
-/* TODO: split into global actions and actions that require a task to be selected */
 static const GtkActionEntry actions[] = 
 {
   /* Action name, stock ID, label, accelerator, tooltip, callback */
@@ -475,6 +479,57 @@ static const GtkActionEntry task_actions[] =
   { "DeleteTask", GTK_STOCK_DELETE, NULL, "<control>Delete", NULL, G_CALLBACK (on_delete_task_action) },
 };
 
+void
+koto_platform_open_url (const char *url)
+{
+  char cmd[1024];
+
+  g_snprintf (cmd, sizeof (cmd), "gnome-open \"%s\"", url);  
+  if (g_spawn_command_line_async (cmd, NULL))
+    return;
+
+  g_snprintf (cmd, sizeof (cmd), "xdg-open \"%s\"", url);  
+  if (g_spawn_command_line_async (cmd, NULL))
+    return;
+
+  g_snprintf (cmd, sizeof (cmd), "firefox \"%s\"", url);  
+  if (g_spawn_command_line_async (cmd, NULL))
+    return;
+
+  g_warning ("Cannot start gnome-open, xdg-open, or firefox");
+}
+
+void
+koto_platform_edit_task (KotoTask *task)
+{
+  g_return_if_fail (task);
+  
+  edit_task (task);
+}
+
+#if WITH_UNIQUE
+static UniqueResponse
+do_message_received (UniqueApp         *app,
+                     gint               command,
+                     UniqueMessageData *message,
+                     guint              time_,
+                     gpointer           user_data)
+{
+  switch (command) {
+  case UNIQUE_ACTIVATE:
+    gtk_window_set_screen (GTK_WINDOW (window),
+			   unique_message_data_get_screen (message));
+    gtk_window_present_with_time (GTK_WINDOW (window), time_);
+    break;
+  default:
+    g_debug ("Unhandled unique command %d", command);
+    break;
+  }
+  
+  return UNIQUE_RESPONSE_OK;
+}
+#endif
+
 int
 main (int argc, char **argv)
 {
@@ -485,6 +540,10 @@ main (int argc, char **argv)
   GtkActionGroup *action_group, *task_action_group;
   GtkUIManager *ui_manager;
   
+#if WITH_UNIQUE
+  UniqueApp *app;
+#endif
+
 #ifdef ENABLE_NLS
   /* Initialise i18n*/
   bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
@@ -494,7 +553,23 @@ main (int argc, char **argv)
 
   g_set_application_name (_("Tasks"));
   gtk_init (&argc, &argv);
-  
+
+#if WITH_UNIQUE
+  app = unique_app_new ("org.pimlico-project.Tasks", NULL);
+
+  if (unique_app_is_running (app)) {
+    UniqueResponse response;
+
+    response = unique_app_send_message (app, UNIQUE_ACTIVATE, NULL);
+
+    gdk_notify_startup_complete ();
+
+    g_object_unref (app);
+
+    return EXIT_SUCCESS;
+  }
+#endif
+
   edit_dialog_hash = g_hash_table_new_full (NULL, NULL, (GDestroyNotify)koto_task_unref, NULL);
 
   undo_manager = koto_undo_manager_new ();
@@ -530,9 +605,14 @@ main (int argc, char **argv)
   gtk_window_set_default_icon_name ("tasks");
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_default_size (GTK_WINDOW (window), 240, 320);
-  window_bind_state (GTK_WINDOW (window));
+  window_bind_state (GTK_WINDOW (window), "main");
   g_signal_connect (window, "destroy", gtk_main_quit, NULL);
 
+#if WITH_UNIQUE
+  unique_app_watch_window (app, GTK_WINDOW (window));
+  g_signal_connect (app, "message-received", G_CALLBACK (do_message_received), NULL);
+#endif
+
   top_box = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), top_box); 
 
@@ -554,7 +634,7 @@ main (int argc, char **argv)
   gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
   gtk_ui_manager_insert_action_group (ui_manager, task_action_group, 0);
 
-  gtk_ui_manager_add_ui_from_file (ui_manager, PKGDATADIR "/tasks-ui.xml", &error);
+  gtk_ui_manager_add_ui_from_string (ui_manager, ui_xml, -1, &error);
   if (error) {
     g_warning ("Cannot load UI: %s", error->message);
     g_error_free (error);
@@ -564,8 +644,13 @@ main (int argc, char **argv)
   gtk_window_add_accel_group (GTK_WINDOW (window), gtk_ui_manager_get_accel_group (ui_manager));
   gtk_ui_manager_ensure_update (ui_manager);
 
+#if WITH_OWL
+  menu = gtk_ui_manager_get_widget (ui_manager, "/OwlMenu/Menu");
+  owl_set_window_menu_item (GTK_WINDOW (window), GTK_MENU_ITEM (menu));
+#else
   menu = gtk_ui_manager_get_widget (ui_manager, "/MenuBar");
   gtk_box_pack_start (GTK_BOX (top_box), menu, FALSE, FALSE, 0);
+#endif
 
   box = gtk_vbox_new (FALSE, 4);
   gtk_container_set_border_width (GTK_CONTAINER (box), 4);
@@ -626,8 +711,12 @@ main (int argc, char **argv)
 
   e_cal_view_start (cal_view);
 
-  gtk_widget_show_all (window);  
+  gtk_widget_show_all (window);
   gtk_main ();
 
-  return 0;
+#if WITH_UNIQUE
+  g_object_unref (app);
+#endif
+
+  return EXIT_SUCCESS;
 }
