@@ -231,6 +231,14 @@ edit_task (KotoTask *task)
   gtk_widget_destroy (dialog);
 }
 
+void
+koto_platform_edit_task (KotoTask *task)
+{
+  g_return_if_fail (task);
+  
+  edit_task (task);
+}
+
 /*
  * Callback when a row in the tree view is activated, which edits the task.
  */
